@@ -6,7 +6,8 @@ use nom::{branch::alt, bytes::complete::tag, combinator::map, IResult};
 use crate::assert_line;
 use crate::parsers::*;
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Clone, PartialEq)]
+#[cfg_attr(feature = "debug", derive(Debug))]
 #[cfg_attr(
     feature = "serde",
     derive(serde::Serialize, serde::Deserialize),
