@@ -10,7 +10,8 @@ use crate::{
 };
 
 /// Sdp Line
-#[derive(Clone, Debug, IntoOwned, EnumAsInner, PartialEq)]
+#[derive(Clone, IntoOwned, EnumAsInner, PartialEq)]
+#[cfg_attr(feature = "debug", derive(Debug))]
 #[cfg_attr(
     feature = "serde",
     derive(serde::Serialize, serde::Deserialize),
